@@ -13,16 +13,15 @@ import warnings  # pylint: disable=unused-import
 from dataclasses import dataclass
 from typing import Any, Dict, List, NewType, Optional, Tuple, Union  # pylint: disable=unused-import
 
-from dataclasses_json import dataclass_json
+from dataclasses_json import DataClassJsonMixin
 
 from annofabapi.models import InspectionStatus, TaskPhase
 
 InspectionData = Dict[str, Any]
 
 
-@dataclass_json
 @dataclass
-class Inspection:
+class Inspection(DataClassJsonMixin):
     """
     検査コメント
     """
